==> spring-cloud-contract-shade-3.1.5-sources.jar: shaded/org/apache/maven/model/profile/ProfileActivationContext.java <==
package shaded.shaded.org.apache.maven.model.profile;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.io.File;
import java.util.List;
import java.util.Map;

/**
 * Describes the environmental context used to determine the activation status of profiles.
 *
 * @author Benjamin Bentmann
 */
public interface ProfileActivationContext
{

    /**
     * Gets the identifiers of those profiles that should be activated by explicit demand.
     *
     * @return The identifiers of those profiles to activate, never {@code null}.
     */
    List<String> getActiveProfileIds();

    /**
     * Gets the identifiers of those profiles that should be deactivated by explicit demand.
     *
     * @return The identifiers of those profiles to deactivate, never {@code null}.
     */
    List<String> getInactiveProfileIds();

    /**
     * Gets the system properties to use for interpolation and profile activation. The system properties are collected
     * from the runtime environment like {@link System#getProperties()} and environment variables.
     *
     * @return The execution properties, never {@code null}.
     */
    Map<String, String> getSystemProperties();

    /**
     * Gets the user properties to use for interpolation and profile activation. The user properties have been
     * configured directly by the user on his discretion, e.g. via the {@code -Dkey=value} parameter on the command
     * line.
     *
     * @return The user properties, never {@code null}.
     */
    Map<String, String> getUserProperties();

    /**
     * Gets the base directory of the current project (if any).
     *
     * @return The base directory of the current project or {@code null} if none.
     */
    File getProjectDirectory();

    /**
     * Gets current calculated project properties
     *
     * @return The project properties, never {@code null}.
     */
    Map<String, String> getProjectProperties();

}

==> spring-cloud-contract-shade-4.1.3-sources.jar: shaded/org/apache/maven/model/profile/ProfileActivationContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package shaded.shaded.org.apache.maven.model.profile;

import java.io.File;
import java.util.List;
import java.util.Map;

/**
 * Describes the environmental context used to determine the activation status of profiles.
 *
 * @author Benjamin Bentmann
 */
public interface ProfileActivationContext {
    /**
     * Key of the property containing the project's packaging.
     * Available in {@link #getUserProperties()}.
     * @since 3.9
     */
    String PROPERTY_NAME_PACKAGING = "packaging";

    /**
     * Gets the identifiers of those profiles that should be activated by explicit demand.
     *
     * @return The identifiers of those profiles to activate, never {@code null}.
     */
    List<String> getActiveProfileIds();

    /**
     * Gets the identifiers of those profiles that should be deactivated by explicit demand.
     *
     * @return The identifiers of those profiles to deactivate, never {@code null}.
     */
    List<String> getInactiveProfileIds();

    /**
     * Gets the system properties to use for interpolation and profile activation. The system properties are collected
     * from the runtime environment like {@link System#getProperties()} and environment variables.
     *
     * @return The execution properties, never {@code null}.
     */
    Map<String, String> getSystemProperties();

    /**
     * Gets the user properties to use for interpolation and profile activation. The user properties have been
     * configured directly by the user on his discretion, e.g. via the {@code -Dkey=value} parameter on the command
     * line.
     *
     * @return The user properties, never {@code null}.
     */
    Map<String, String> getUserProperties();

    /**
     * Gets the base directory of the current project (if any).
     *
     * @return The base directory of the current project or {@code null} if none.
     */
    File getProjectDirectory();

    /**
     * Gets current calculated project properties
     *
     * @return The project properties, never {@code null}.
     */
    Map<String, String> getProjectProperties();
}
